## New feature

(Describe the new functionality)

## Use case

(Describe how/why the functionality is relevant and in which context it can be used)

## Suggested implementation

(Highlight the main building blocks of a possible implementation)

/label ~enhancement
